use egui::{Stroke, Vec2};

use super::{CompGetter, CompUi};


#[derive(Debug, Default)]
pub struct Player {
    slider_progress: usize
}

component_register!(Player);


impl CompUi for Player {
    fn draw(ui: &mut egui::Ui, state: &mut crate::GuiState) -> crate::Result<()> {
        let avail = ui.available_size();
        ui.vertical_centered_justified(|ui| {
            ui.add_space(3.0);
            ui.horizontal(|ui| {
                {
                    ui.add_space(avail.x * 0.05 / 2.0);
                    let mut slf = handle_error_ui!(Player::get());
                    let slider = egui::Slider::new(&mut slf.slider_progress, 0..=100)
                        .show_value(false);
                    ui.style_mut().spacing.slider_width = avail.x * 0.90;
                    let s = Stroke {
                        color: crate::data::C_ACCENT,
                        width: 2.0
                    };
                    ui.style_mut().visuals.widgets.inactive.fg_stroke = s;
                    ui.style_mut().visuals.widgets.active.fg_stroke = s;
                    ui.add(slider);
                    ui.label("00:00");
                }
            });
            ui.horizontal(|ui| {
                ui.add_space((avail.x / 2.0) - 16.0 - 8.0 - ui.spacing().item_spacing.x);
                let prev = egui::Image::new(crate::data::PREV_ICON)
                    .tint(crate::data::C_ACCENT)
                    .max_size(Vec2::new(16.0, 16.0));
                let play = egui::Image::new(crate::data::PLAY_ICON)
                    .tint(crate::data::C_ACCENT)
                    .max_size(Vec2::new(16.0, 16.0));
                let next = egui::Image::new(crate::data::NEXT_ICON)
                    .tint(crate::data::C_ACCENT)
                    .max_size(Vec2::new(16.0, 16.0));
                if ui.add(prev).clicked() {}
                if ui.add(play).clicked() {}
                if ui.add(next).clicked() {}
            });
            ui.add_space(3.0);
        });
        Ok(())
    }
}
